@@ -4,23 +4,20 @@ import logging
 import os
 from glob import glob
 
-from np_lims_tk.core import (
-    get_project_asset,
-    get_project_name,
-    project_name_to_data_manifestor_template,
-    put_project_asset,
-)
+from np_lims_tk.core import get_project_asset, get_project_name, put_project_asset
 from np_lims_tk.local_paths import path_to_lims_meta
 
-from .dataclasses import LocalComparisonResult, Manifest, Template
 from .exceptions import ManifestError, PathError
-from .paths import generate_path_pattern, resolve_paths
-from .transformers import (
+from .models import (
+    LocalComparisonResult,
+    Manifest,
+    Template,
     alt_dict_to_template,
     dict_to_template,
     dump_Template,
     is_alt_format,
 )
+from .paths import generate_path_pattern, resolve_paths
 
 logger = logging.getLogger(__name__)
 
@@ -107,7 +104,8 @@ def path_to_manifest_template(path: str) -> tuple[Any, tuple[Any, ...]]:
         date_str = lims_meta.date_str
         project_name = get_project_name(lims_id=lims_id)
         logger.debug("Resolved project name: %s" % project_name)
-        return project_name_to_data_manifestor_template(project_name), (
+        template = get_project_data_manifestor_template(project_name)
+        return template, (
             lims_id,
             subject_id,
             date_str,
